// based on the esp-now tutorial found here:
// https://randomnerdtutorials.com/esp-now-esp32-arduino-ide/

#include <esp_now.h>
#include <WiFi.h>

const int btn_five_pin = 5;
const int btn_six_pin = 6;
const int btn_nine_pin = 20;


int buttonState = 0;   
int previousButtonState = HIGH;

// RECEIVER'S MAC Address
uint8_t broadcastAddress[] = {*MAC ADDRESS HERE*};

// Must match the receiver structure
typedef struct struct_message {
    int id;
    int key;
} struct_message;

// Create a struct_message called myData
struct_message myData;

// Create peer interface
esp_now_peer_info_t peerInfo;

// callback when data is sent
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.print("\r\nLast Packet Send Status:\t");
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}
 
void setup() {
  // Init Serial Monitor
  Serial.begin(115200);

  // these pins set to high on esp reset, need to set them low on startup to prevent the leds from being on constantly 
  pinMode(btn_six_pin, OUTPUT);
  digitalWrite(btn_six_pin, LOW);
  pinMode(btn_nine_pin, OUTPUT);
  digitalWrite(btn_nine_pin, LOW);
  
  // make the pushButton pin an input:
  pinMode(btn_five_pin, INPUT);

  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);

  // Init ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }

  // Once ESPNow is successfully Init, we will register for Send CB to
  // get the status of Trasnmitted packet
  esp_now_register_send_cb(OnDataSent);
  
  // Register peer
  memcpy(peerInfo.peer_addr, broadcastAddress, 6);
  peerInfo.channel = 0;  
  peerInfo.encrypt = false;
  
  // Add peer        
  if (esp_now_add_peer(&peerInfo) != ESP_OK){
    Serial.println("Failed to add peer");
    return;
  }
}
 
void loop() {
  // read the state of the pushbutton value:
  buttonState = digitalRead(btn_five_pin);

  if ((buttonState != previousButtonState) && (buttonState == HIGH)) {
    // Set values to send
    myData.id = 2;
    myData.key = 5; // receiver reads the key value and does appropriate action  
    
    // Send message via ESP-NOW
    esp_err_t result = esp_now_send(broadcastAddress, (uint8_t *) &myData, sizeof(myData));
  
    if (result == ESP_OK) {
      Serial.println("Sent with success");
      Serial.println(buttonState);
    }
    else {
      Serial.println("Error sending the data");
    }
  }
  previousButtonState = buttonState;
  delay(100);

}
